<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Add payment details to the Booking Modal
 * 
 * @param WPBS_Booking
 * 
 */
function wpbs_pp_booking_modal_payment_tab_content($booking)
{
    $payment = wpbs_get_payment_by_booking_id($booking->get('id'));

    // Check if there is an order for this booking
    if (empty($payment)) {
        return false;
    }

    // Check if it's a PayPal order
    if($payment->get('gateway') != 'paypal'){
        return false;
    }

    $order_details = $payment->get('details');
    $paypal_data = $order_details['raw'];

    // Payment Information
    $payment_information = array(
        array('label' => __('Order Status', 'wp-booking-system-paypal'),        'value' => ucwords($payment->get('order_status'))),
        array('label' => __('Payment Gateway', 'wp-booking-system-paypal'),     'value' => 'PayPal'),
        array('label' => __('Date', 'wp-booking-system-paypal'),                'value' => date('j F Y, H:i:s', strtotime($payment->get('date_created')))),
        array('label' => __('ID', 'wp-booking-system-paypal'),                  'value' => '#' . $payment->get('id')),
    );

    if($payment->get('order_status') == 'error'){
        $payment_information[] = array('label' => __('Error', 'wp-booking-system-paypal'), 'value' => $order_details['error']);
    }

    if(isset($paypal_data['result'])){
        $payment_information[] = array('label' => __('Transaction ID', 'wp-booking-system-paypal'),      'value' => $paypal_data['result']['purchase_units'][0]['payments']['captures'][0]['id']);
        $payment_information[] = array('label' => __('Buyer Name', 'wp-booking-system-paypal'),          'value' => $paypal_data['result']['payer']['name']['surname'] . ' ' . $paypal_data['result']['payer']['name']['given_name']);
        $payment_information[] = array('label' => __('Buyer Email Address', 'wp-booking-system-paypal'), 'value' => $paypal_data['result']['payer']['email_address']);
        $payment_information[] = array('label' => __('Buyer Country Code', 'wp-booking-system-paypal'),  'value' => $paypal_data['result']['payer']['address']['country_code']);
    }

    // Order Information
    $order_information = $payment->get_line_items();

    $order_information = apply_filters('wpbs_booking_details_order_information', $order_information, $payment);

    $amount_received = (isset($paypal_data['result']['purchase_units'][0]['amount']['value'])) ? $paypal_data['result']['purchase_units'][0]['amount']['value'] : 0;

    $order_information[] = array('label' => __('Amount Received', 'wp-booking-system-paypal'), 'value' => wpbs_get_formatted_price($amount_received, strtoupper($payment->get_currency())));

    // Include view file
    include WPBS_PLUGIN_DIR . '/includes/modules/pricing/booking/views/view-modal-payment-details-content.php';

}
add_action('wpbs_booking_modal_tab_content_payment', 'wpbs_pp_booking_modal_payment_tab_content', 10, 1);
