<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Ignore reCaptcha on confirmation screen
 *
 */
function wpbs_validate_recaptcha_payment_confirmation_paypal($response, $form_data)
{
    if (isset($form_data['wpbs-paypal-confirmation-loaded']) && $form_data['wpbs-paypal-confirmation-loaded'] == '1') {
        return true;
    }
    return $response;
}
add_filter('wpbs_validate_recaptcha_payment_confirmation', 'wpbs_validate_recaptcha_payment_confirmation_paypal', 10, 2);

/**
 * Show the payment confirmation page after submitting the form
 *
 */
function wpbs_pp_submit_form_payment_confirmation($response, $post_data, $form, $form_args, $form_fields, $calendar_id)
{

    // Check if another payment method was already found
    if ($response !== false) {
        return $response;
    }

    $payment_found = false;

    // Check if payment method is enabled.
    foreach ($form_fields as $form_field) {
        if ($form_field['type'] == 'payment_method' && $form_field['user_value'] == 'paypal') {
            $payment_found = true;
            break;
        }
    }

    if ($payment_found === false) {
        return false;
    }

    // Parse POST data
    parse_str($post_data['form_data'], $form_data);

    // Check if the payment screen was shown
    if (isset($form_data['wpbs-paypal-confirmation-loaded']) && $form_data['wpbs-paypal-confirmation-loaded'] == '1') {
        return false;
    }

    // Add a field to the input so we can check if the payment screen was already shown
    add_filter('wpbs_form_outputter_form_fields_after', function () {
        return '<input type="hidden" name="wpbs-paypal-confirmation-loaded" value="1" />';
    });

    // Generate form
    $form_outputter = new WPBS_Form_Outputter($form, $form_args, $form_fields, $calendar_id);

    // Check if post data exists and matches form values
    if (wpbs_validate_payment_form_consistency($form_fields) === false) {
        return json_encode(
            array(
                'success' => false,
                'html' => '<strong>' . __('Something went wrong. Please refresh the page and try again.', 'wp-booking-system-paypal') . '</strong>',
            )
        );
    }

    // Get price
    $payment = new WPBS_Payment;
    $payment->calculate_prices($post_data, $form, $form_args, $form_fields);

    $total = $payment->get_total();

    // Check if part payments are used
    if (wpbs_part_payments_enabled() == true && $payment->is_part_payment()) {
        $total = $payment->get_total_first_payment();
    }

    // Check if price is greater than the minimum allowed, 0.01;
    if ($total <= 0.01) {
        return json_encode(
            array(
                'success' => false,
                'html' => '<p class="wpbs-form-general-error">' . __("The minimum payable amount is 0.01$", 'wp-booking-system-paypal') . '</p>',
            )
        );
    }

    // Check if we support the currency
    if (!in_array($payment->get_currency(), wpbs_pp_supported_currencies())) {
        return json_encode(
            array(
                'success' => false,
                'html' => '<p class="wpbs-form-general-error">' . __("This currency is not supported by PayPal.", 'wp-booking-system-paypal') . '</p>',
            )
        );
    }

    

    // Get plugin settings
    $settings = get_option('wpbs_settings', array());

    // Invoice item description
    $invoice_item_description = (!empty($settings['payment_paypal_invoice_name_translation_' . $form_outputter->get_language()])) ? $settings['payment_paypal_invoice_name_translation_' . $form_outputter->get_language()] : (!empty($settings['payment_paypal_invoice_name']) ? $settings['payment_paypal_invoice_name'] : get_bloginfo('name') . ' Booking');

    // Get API Keys
    include_once WPBS_PP_PLUGIN_DIR . 'includes/libs/paypal-checkout-sdk/paypal-checkout-sdk.php';
    $api = WPBS_PayPal_API::keys();

    /**
     * Prepare Response
     *
     */
    $paypal_output = '';
    if ($api['environment'] == 'sandbox') {
        $paypal_output .= '<p class="wpbs-payment-test-mode-enabled">' . __('PayPal Sandbox mode is enabled.', 'wp-booking-system-paypal') . '</p>';
    }

    if (wpbs_part_payments_enabled() == true && $payment->is_part_payment()) {
        $paypal_output .= '<label>' . wpbs_get_payment_default_string('amount_billed', $form_outputter->get_language()) . '</label><input class="wpbs-payment-confirmation-paypal-input" type="text" value="' . wpbs_get_formatted_price($total, $payment->get_currency()) . '" readonly>';
    }

    $locale = wpbs_pp_locale(get_locale());

    $paypal_output .= '
    <div id="wpbs-paypal-button-container-' . $form_outputter->get_unique() . '"></div>
    <script>
        wpbs_lazy_load_script("https://www.paypal.com/sdk/js?client-id=' . $api['client_id'] . '&currency=' . $payment->get_currency() . '&locale=' . $locale . '", wpbs_init_paypal)
        function wpbs_init_paypal(){
            if(typeof paypal === "undefined"){
                jQuery("#wpbs-paypal-button-container-' . $form_outputter->get_unique() . '").html("<p class=\"wpbs-form-general-error\">' . __('Something went wrong. Please check if your API keys are correct.', 'wp-booking-system-paypal') . '</p>");
            } else {
                paypal.Buttons({
                    createOrder: function(data, actions) {
                        return actions.order.create({
                            purchase_units: [{
                            description: "' . $invoice_item_description . '",
                            amount: {
                                value: "' . $total . '",
                                currency : "' . $payment->get_currency() . '"
                            }
                            }],
                            application_context: {
                                shipping_preference: "NO_SHIPPING"
                            }
                        });
                    },
                    onApprove: function(data, actions) {

                        jQuery(".wpbs-paypal-payment-confirmation-inner-' . $form_outputter->get_unique() . '").hide();
                        jQuery(".wpbs-paypal-payment-confirmation-' . $form_outputter->get_unique() . '").append("<h4>' . wpbs_get_payment_default_string('processing_payment', $form_outputter->get_language()) . '</h4>");
                        jQuery(".wpbs-paypal-payment-confirmation-' . $form_outputter->get_unique() . '").parents(".wpbs-main-wrapper").find(".wpbs-calendar").append("<div class=\"wpbs-overlay\"><div class=\"wpbs-overlay-spinner\"><div class=\"wpbs-overlay-bounce1\"></div><div class=\"wpbs-overlay-bounce2\"></div><div class=\"wpbs-overlay-bounce3\"></div></div></div>");
                        jQuery(".wpbs-paypal-payment-confirmation-' . $form_outputter->get_unique() . '").parents(".wpbs-container").addClass("wpbs-is-loading");
                        jQuery(".wpbs-paypal-payment-confirmation-' . $form_outputter->get_unique() . ' form").append("<input type=\"hidden\" name=\"wpbs-paypal-order-id\" value=\""+data.orderID+"\" />")
                        jQuery(".wpbs-paypal-payment-confirmation-' . $form_outputter->get_unique() . ' form").append("<input type=\"hidden\" name=\"wpbs-custom-currency\" value=\"'. $payment->get_currency().'\" />")
                        jQuery(".wpbs-paypal-payment-confirmation-' . $form_outputter->get_unique() . ' form").submit();
                    },
                    onError: function (error){
                        jQuery("#wpbs-paypal-button-container-' . $form_outputter->get_unique() . '").html("<p class=\"wpbs-form-general-error\">' . __('Something went wrong. Please check your browser console for details.', 'wp-booking-system-paypal') . '</p>");
                        console.log(error);
                    }
                }).render("#wpbs-paypal-button-container-' . $form_outputter->get_unique() . '");
            }
            jQuery("#wpbs-paypal-button-container-' . $form_outputter->get_unique() . '").parents(".wpbs-main-wrapper").find(".wpbs-container").addClass("wpbs-disable-selection");
        }
    </script>';

    $output = wpbs_form_payment_confirmation_screen($form_outputter, $payment, 'paypal', $paypal_output);

    return json_encode(
        array(
            'success' => false,
            'html' => $output,
        )
    );

}
add_filter('wpbs_submit_form_before', 'wpbs_pp_submit_form_payment_confirmation', 20, 6);

/**
 * Save the order in the database
 *
 */
function wpbs_pp_action_save_payment_details($booking_id, $post_data, $form, $form_args, $form_fields)
{

    // Parse POST data
    parse_str($post_data['form_data'], $form_data);

    // Check if paypal is enabled
    if (!isset($form_data['wpbs-paypal-confirmation-loaded'])) {
        return false;
    }

    // Check if we got an order ID
    if (!isset($form_data['wpbs-paypal-order-id'])) {
        return false;
    }

    // Include Paypal SDK
    include_once WPBS_PP_PLUGIN_DIR . 'includes/libs/paypal-checkout-sdk/paypal-checkout-sdk.php';

    // Get price
    $payment = new WPBS_Payment;
    $details['price'] = $payment->calculate_prices($post_data, $form, $form_args, $form_fields);

    if (wpbs_part_payments_enabled() == true && $payment->is_part_payment()) {
        $details['part_payments'] = array('deposit' => false, 'final_payment' => false);
    }

    // Capture Order
    $capture = WPBS_PayPal_CaptureOrder::captureOrder($form_data['wpbs-paypal-order-id']);
    
    if ($capture['success'] == true) {
        // Get Order
        $order = WPBS_PayPal_GetOrder::getOrder($form_data['wpbs-paypal-order-id']);

        $details['raw'] = $order['data'];

        if (isset($details['part_payments']['deposit'])) {
            $details['part_payments']['deposit'] = true;
        }

        $status = 'completed';
        $id = 'pp_' . $order['data']->result->id;
    } else {
        $details['error'] = $capture['error'];
        $status = 'error';
        $id = 'N/A';
    }

    // Save Order
    wpbs_insert_payment(array(
        'booking_id' => $booking_id,
        'gateway' => 'paypal',
        'order_id' => $id,
        'order_status' => $status,
        'details' => $details,
        'date_created' => current_time('Y-m-d H:i:s'),
    ));

}
add_action('wpbs_submit_form_after', 'wpbs_pp_action_save_payment_details', 20, 5);
