<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Display the final payment of the part payments checkout form.
 * 
 * @param string $output 
 * @param WPBS_Payment $order
 * @param string $language
 * 
 * @return string
 * 
 */
function wpbs_final_payment_paypal($output, $payment, $language)
{

    // Get total amount
    $total = $payment->get_total_second_payment();

    // Include PayPal API
    include_once WPBS_PP_PLUGIN_DIR . 'includes/libs/paypal-checkout-sdk/paypal-checkout-sdk.php';

    // Get API Keys
    $api = WPBS_PayPal_API::keys();

    // Get plugin settings
    $settings = get_option('wpbs_settings', array());

    // Invoice item description
    $invoice_item_description = (!empty($settings['payment_paypal_invoice_name_translation_' . $language])) ? $settings['payment_paypal_invoice_name_translation_' . $language] : (!empty($settings['payment_paypal_invoice_name']) ? $settings['payment_paypal_invoice_name'] : get_bloginfo('name') . ' Booking');

    /**
     * Prepare Response
     *
     */
    $output = '';
    if ($api['environment'] == 'sandbox') {
        $output .= '<p class="wpbs-payment-test-mode-enabled">' . __('PayPal Sandbox mode is enabled.', 'wp-booking-system-paypal') . '</p>';
    }

    if (wpbs_part_payments_enabled() == true && $payment->is_part_payment()) {
        $output .= '<label>' . wpbs_get_payment_default_string('amount_billed', $language) . '</label><input class="wpbs-payment-confirmation-paypal-input" type="text" value="' . wpbs_get_formatted_price($total, $payment->get_currency()) . '" readonly>';
    }

    $locale = wpbs_pp_locale(get_locale());

    $output .= '
    <div id="wpbs-paypal-button-container"></div>
    <script>
        jQuery(document).ready(function(){
            wpbs_lazy_load_script("https://www.paypal.com/sdk/js?client-id=' . $api['client_id'] . '&currency=' . $payment->get_currency() . '&locale=' . $locale . '", wpbs_init_paypal)
        });
        function wpbs_init_paypal(){
            if(typeof paypal === "undefined"){
                jQuery("#wpbs-paypal-button-container").html("<p class=\"wpbs-form-general-error\">' . __('Something went wrong. Please check if your API keys are correct.', 'wp-booking-system-paypal') . '</p>");
            } else {
                paypal.Buttons({
                    createOrder: function(data, actions) {
                        return actions.order.create({
                            purchase_units: [{
                            description: "' . $invoice_item_description . '",
                            amount: {
                                value: "' . $total . '",
                                currency : "' . $payment->get_currency() . '"
                            }
                            }],
                            application_context: {
                                shipping_preference: "NO_SHIPPING"
                            }
                        });
                    },
                    onApprove: function(data, actions) {

                        jQuery(".wpbs-paypal-payment-confirmation-inner").hide();
                        jQuery(".wpbs-final-payment-confirmation").append("<h4>' . wpbs_get_payment_default_string('processing_payment', $language) . '</h4>");
                        jQuery(".wpbs-final-payment-confirmation").append("<div class=\"wpbs-overlay\"><div class=\"wpbs-overlay-spinner\"><div class=\"wpbs-overlay-bounce1\"></div><div class=\"wpbs-overlay-bounce2\"></div><div class=\"wpbs-overlay-bounce3\"></div></div></div>");
                        jQuery(".wpbs-final-payment-confirmation form").append("<input type=\"hidden\" name=\"wpbs-paypal-order-id\" value=\""+data.orderID+"\" />")
                        jQuery(".wpbs-final-payment-confirmation form").submit();
                    },
                    onError: function (error){
                        jQuery("#wpbs-paypal-button-container").html("<p class=\"wpbs-form-general-error\">' . __('Something went wrong. Please check your browser console for details.', 'wp-booking-system-paypal') . '</p>");
                        console.log(error);
                    }
                }).render("#wpbs-paypal-button-container");
            }
        }
        
    </script>';

    return $output;

}
add_filter('wpbs_final_payment_paypal', 'wpbs_final_payment_paypal', 10, 3);


/**
 * Process the final payment of the part payments checkout form.
 * 
 * @param array $post_data 
 * @param WPBS_Payment $payment
 * 
 */
function wpbs_save_final_payment_paypal($post_data, $payment)
{

    // Check if we got an order ID
    if (!isset($post_data['wpbs-paypal-order-id'])) {
        return wp_die();
    }

    // Get site options
    $settings = get_option('wpbs_settings', array());

    // Include Paypal SDK
    include_once WPBS_PP_PLUGIN_DIR . 'includes/libs/paypal-checkout-sdk/paypal-checkout-sdk.php';

    // Get price
    $details = $payment->get('details');

    // Check if final payment wasn't made yet
    if ($payment->is_final_payment_paid()) {
        wp_die();
    }

    // Capture Order
    $capture = WPBS_PayPal_CaptureOrder::captureOrder($post_data['wpbs-paypal-order-id']);

    if ($capture['success'] == true) {

        $order = WPBS_PayPal_GetOrder::getOrder($post_data['wpbs-paypal-order-id']);
        $details['final_payment'] = $order['data'];
        $details['part_payments']['final_payment'] = true;

        $details['raw']['result']['purchase_units'][0]['amount']['value'] = $details['raw']['result']['purchase_units'][0]['amount']['value'] + $order['data']->result->purchase_units[0]->amount->value;

        $status = 'completed';
    } else {
        $details['error'] = $capture['error'];
        $status = 'error';
    }

    $payment_data = array(
        'order_status' => $status,
        'details' => $details,
    );

    // Save Order
    wpbs_update_payment($payment->get('id'), $payment_data);
}
add_action('wpbs_save_final_payment_paypal', 'wpbs_save_final_payment_paypal', 10, 2);
