<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

add_filter('wpbs_payment_details_refunds_available', function ($status, $payment) {
    if ($payment->get_payment_gateway() == 'paypal') {
        return true;
    }
    return $status;
}, 10, 2);

add_filter('wpbs_payment_details_refund_charges', function ($charges, $payment) {

    if ($payment->get_payment_gateway() != 'paypal') {
        return $charges;
    }


    $payment_details = $payment->get('details');

    include_once WPBS_PP_PLUGIN_DIR . 'includes/libs/paypal-checkout-sdk/paypal-checkout-sdk.php';

    $charge_ids = [];

    if (!$payment->is_part_payment() && isset($payment_details['raw']['result']['id'])) {
        $charge_ids[] = [
            'id' => $payment_details['raw']['result']['id'],
            'name' => 'Charge',
        ];
    } else {
        
        if ($payment->is_deposit_paid() && isset($payment_details['raw']['result']['id'])) {
            $charge_ids[] = [
                'id' => trim(explode(',', $payment_details['raw']['result']['id'])[0]),
                'name' => __('Deposit', 'wp-booking-system-paypal'),
            ];
        }
        if ($payment->is_final_payment_paid() && isset($payment_details['final_payment']['result']['id'])) {
            $charge_ids[] = [
                'id' => $payment_details['final_payment']['result']['id'],
                'name' => __('Final Payment', 'wp-booking-system-paypal'),
            ];
        }
    }

    $refunds = [];
    if(isset($payment_details['refunds'])){
        foreach($payment_details['refunds'] as $refund){
            if(!isset($refunds[$refund['charge']])){
                $refunds[$refund['charge']] = 0;
            }

            $refunds[$refund['charge']] += $refund['amount'];
        }  
    }

    foreach ($charge_ids as $charge_id) {
        
        $charge = WPBS_PayPal_GetOrder::getOrder($charge_id['id']);
        if (!$charge['success']) {
            echo $charge['error'];
            wp_die();
        }

        $id = $charge['data']->result->purchase_units[0]->payments->captures[0]->id;

        $refunded = isset($refunds[$id]) ? $refunds[$id] : 0;

        $amount = $charge['data']->result->purchase_units[0]->payments->captures[0]->amount->value;

        $charges[] = [
            'name' => $charge_id['name'],
            'id' => $id,
            'amount' => $amount,
            'refunded' => $refunded,
            'available' => ($amount - $refunded),
        ];

    }

    return $charges;
}, 10, 3);

/**
 * Remove scheduled event
 *
 */
function wpbs_process_refund_paypal($charge_id, $amount, $payment)
{

    if (empty($charge_id)) {
        return ['error' => true, 'error_message' => 'Missing Charge ID'];
    }

    if (empty($amount)) {
        return ['error' => true, 'error_message' => 'Missing Amount'];
    }

    $amount = floatval($amount);

    // Include PayPal API
    include_once WPBS_PP_PLUGIN_DIR . 'includes/libs/paypal-checkout-sdk/paypal-checkout-sdk.php';

    $response = WPBS_PayPal_RefundOrder::refundOrder($charge_id, $amount, $payment->get_currency());

    if (isset($response['error']) && $response['error']) {
        $error = json_decode($response['error']);
        return ['error' => true, 'error_message' => $error->details[0]->issue . ': ' . $error->details[0]->description];
    }

    return ['success' => true, 'response' => $response['response'], 'amount' => $amount];

}
