<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Includes the Base files
 *
 */
function wpbs_pp_include_files_base()
{
    // Get legend dir path
    $dir_path = plugin_dir_path(__FILE__);

    // Include Payment Ajax Functions
    if (file_exists($dir_path . 'functions-actions-paypal.php')) {
        include $dir_path . 'functions-actions-paypal.php';
    }

    // Include Part Payments Functions
    if (file_exists($dir_path . 'functions-part-payments.php')) {
        include $dir_path . 'functions-part-payments.php';
    }

    // Include Refund Functions
    if (file_exists($dir_path . 'functions-refunds.php')) {
        include $dir_path . 'functions-refunds.php';
    }
    
}
add_action('wpbs_pp_include_files', 'wpbs_pp_include_files_base');

/**
 * Register Payment Method
 *
 * @param array
 *
 */
function wpbs_pp_register_payment_method($payment_methods)
{
    $payment_methods['paypal'] = 'PayPal';
    return $payment_methods;
}
add_filter('wpbs_payment_methods', 'wpbs_pp_register_payment_method');

/**
 * Default form values
 *
 */
function wpbs_pp_settings_paypal_defaults()
{
    return array(
        'display_name' => __('PayPal', 'wp-booking-system-paypal'),
        'description' => __('Pay with your PayPal account or your credit card.', 'wp-booking-system-paypal'),
    );
}

/**
 * Check if payment method is enabled in settings page
 *
 */
function wpbs_pp_form_outputter_payment_method_enabled_paypal($active)
{
    $settings = get_option('wpbs_settings', array());
    if (isset($settings['payment_paypal_enable']) && $settings['payment_paypal_enable'] == 'on') {
        return true;
    }
    return false;
}
add_filter('wpbs_form_outputter_payment_method_enabled_paypal', 'wpbs_pp_form_outputter_payment_method_enabled_paypal');

/**
 * Get the payment method's name
 *
 */
function wpbs_pp_form_outputter_payment_method_name_paypal($active, $language)
{
    $settings = get_option('wpbs_settings', array());
    if (!empty($settings['payment_paypal_name_translation_' . $language])) {
        return $settings['payment_paypal_name_translation_' . $language];
    }
    if (!empty($settings['payment_paypal_name'])) {
        return $settings['payment_paypal_name'];
    }
    return wpbs_pp_settings_paypal_defaults()['display_name'];
}
add_filter('wpbs_form_outputter_payment_method_name_paypal', 'wpbs_pp_form_outputter_payment_method_name_paypal', 10, 2);

/**
 * Get the payment method's name
 *
 */
function wpbs_pp_form_outputter_payment_method_description_paypal($active, $language)
{
    $settings = get_option('wpbs_settings', array());
    if (!empty($settings['payment_paypal_description_translation_' . $language])) {
        return $settings['payment_paypal_description_translation_' . $language];
    }
    if (!empty($settings['payment_paypal_description'])) {
        return $settings['payment_paypal_description'];
    }
    return wpbs_pp_settings_paypal_defaults()['description'];
}
add_filter('wpbs_form_outputter_payment_method_description_paypal', 'wpbs_pp_form_outputter_payment_method_description_paypal', 10, 2);

/**
 * Return an array with the supported currencies
 * 
 * @return array
 */
function wpbs_pp_supported_currencies(){
    return array('AUD','BRL','CAD','CZK','DKK','EUR','HKD','HUF','INR','ILS','JPY','MYR','MXN','TWD','NZD','NOK','PHP','PLN','GBP','RUB','SGD','SEK','CHF','THB','USD');
}

/**
 * Fix locale for some languages
 * 
 * @param string $locale
 * 
 * @return string
 * 
 */
function wpbs_pp_locale($locale){
    if(strpos($locale,'_') === false){
        return wpbs_language_to_locale($locale);
    }
    return $locale;
}